[U-Boot] [PATCH v2 08/10] patman: Add a maintainer test feature to MakeCcFile()

Simon Glass sjg at chromium.org
Mon May 29 21:31:29 UTC 2017


Allow the add_maintainers parameter to be a list of maintainers, thus
allowing us to simulate calling the script in tests without actually
needing it to work.

Signed-off-by: Simon Glass <sjg at chromium.org>
---

Changes in v2: None

 tools/patman/series.py | 8 ++++++--
 1 file changed, 6 insertions(+), 2 deletions(-)

diff --git a/tools/patman/series.py b/tools/patman/series.py
index 7a3534fee9..395b9ea99b 100644
--- a/tools/patman/series.py
+++ b/tools/patman/series.py
@@ -212,7 +212,9 @@ class Series(dict):
             cover_fname: If non-None the name of the cover letter.
             raise_on_error: True to raise an error when an alias fails to match,
                 False to just print a message.
-            add_maintainers: Call the get_maintainers to CC maintainers
+            add_maintainers: Either:
+                True/False to call the get_maintainers to CC maintainers
+                List of maintainers to include (for testing)
         Return:
             Filename of temp file created
         """
@@ -227,7 +229,9 @@ class Series(dict):
                                                raise_on_error=raise_on_error)
             list += gitutil.BuildEmailList(commit.cc_list,
                                            raise_on_error=raise_on_error)
-            if add_maintainers:
+            if type(add_maintainers) == type(list):
+                list += add_maintainers
+            elif add_maintainers:
                 list += get_maintainer.GetMaintainer(commit.patch)
             list = [m.encode('utf-8') if type(m) != str else m for m in list]
             all_ccs += list
-- 
2.13.0.219.gdb65acc882-goog



More information about the U-Boot mailing list